EXPORTS
	?CancelAsynchronousData@RAlfTfxClient@@QAEXABVTUid@@H@Z @ 1 NONAME ; void RAlfTfxClient::CancelAsynchronousData(class TUid const &, int)
	?LoadTfxPlugin@RAlfTfxClient@@QAEHABVTUid@@@Z @ 2 NONAME ; int RAlfTfxClient::LoadTfxPlugin(class TUid const &)
	?Open@RAlfTfxClient@@QAEHXZ @ 3 NONAME ; int RAlfTfxClient::Open(void)
	?SendAsynchronousData@RAlfTfxClient@@QAEXABVTUid@@ABVTDesC8@@AAVTDes8@@AAVTRequestStatus@@@Z @ 4 NONAME ; void RAlfTfxClient::SendAsynchronousData(class TUid const &, class TDesC8 const &, class TDes8 &, class TRequestStatus &)
	?SendSynchronousData@RAlfTfxClient@@QAEHABVTUid@@ABVTDesC8@@AAVTDes8@@@Z @ 5 NONAME ; int RAlfTfxClient::SendSynchronousData(class TUid const &, class TDesC8 const &, class TDes8 &)
	?UnloadTfxPlugin@RAlfTfxClient@@QAEXABVTUid@@@Z @ 6 NONAME ; void RAlfTfxClient::UnloadTfxPlugin(class TUid const &)
	?PrepareFrame@RAlfTfxClient@@QAEXI@Z @ 7 NONAME ; void RAlfTfxClient::PrepareFrame(unsigned int)
	?Connect@RAlfBridgerClient@@QAEHXZ @ 8 NONAME ; int RAlfBridgerClient::Connect(void)
	?SendSynch@RAlfBridgerClient@@QAEHHABVTDesC8@@@Z @ 9 NONAME ; int RAlfBridgerClient::SendSynch(int, class TDesC8 const &)
	?SendSynch@RAlfBridgerClient@@QAEHHABVTIpcArgs@@@Z @ 10 NONAME ; int RAlfBridgerClient::SendSynch(int, class TIpcArgs const &)
	?SendAsynchronous@RAlfBridgerClient@@QAEXHABVTIpcArgs@@AAVTRequestStatus@@@Z @ 11 NONAME ; void RAlfBridgerClient::SendAsynchronous(int, class TIpcArgs const &, class TRequestStatus &)
	?SendBlind@RAlfBridgerClient@@QAEHHABVTIpcArgs@@@Z @ 12 NONAME ; int RAlfBridgerClient::SendBlind(int, class TIpcArgs const &)
	?StartL@AlfServerStarter@@SAXAAVTRequestStatus@@H@Z @ 13 NONAME ; void AlfServerStarter::StartL(class TRequestStatus &, int)
	?SetHandleL@CAlfCompositionClientBase@@IAEXH@Z @ 14 NONAME ; void CAlfCompositionClientBase::SetHandleL(int)
	?SetZOrder@CAlfCompositionSource@@QAEHABVCAlfCompositionClientBase@@HH@Z @ 15 NONAME ; int CAlfCompositionSource::SetZOrder(class CAlfCompositionClientBase const &, int, int)
	??1CAlfCompositionClientBase@@MAE@XZ @ 16 NONAME ; CAlfCompositionClientBase::~CAlfCompositionClientBase(void)
	?HandleEventL@CAlfCompositionSource@@MAEXHPAX@Z @ 17 NONAME ; void CAlfCompositionSource::HandleEventL(int, void *)
	?AddCompositionObserverL@CAlfCompositionSource@@QAEXAAVMAlfCompositionObserver@@H@Z @ 18 NONAME ; void CAlfCompositionSource::AddCompositionObserverL(class MAlfCompositionObserver &, int)
	?SetRotation@CAlfCompositionSource@@UAEHH@Z @ 19 NONAME ; int CAlfCompositionSource::SetRotation(int)
	?SetOpacity@CAlfCompositionSource@@UAEHM@Z @ 20 NONAME ; int CAlfCompositionSource::SetOpacity(float)
	?NewL@CAlfCompositionCntrlClient@@SAPAV1@PAVRAlfBridgerClient@@PAVMAlfCompositionController@@@Z @ 21 NONAME ; class CAlfCompositionCntrlClient * CAlfCompositionCntrlClient::NewL(class RAlfBridgerClient *, class MAlfCompositionController *)
	?RunError@CAlfCompositionClientBase@@MAEHH@Z @ 22 NONAME ; int CAlfCompositionClientBase::RunError(int)
	?RequestEventL@CAlfCompositionClientBase@@IAEXHPAVRAlfBridgerClient@@@Z @ 23 NONAME ; void CAlfCompositionClientBase::RequestEventL(int, class RAlfBridgerClient *)
	??1CAlfCompositionPixelSource@@UAE@XZ @ 24 NONAME ; CAlfCompositionPixelSource::~CAlfCompositionPixelSource(void)
	?NewL@CAlfCompositionPixelSource@@SAPAV1@AAVMAlfBufferProvider@@PAVRWindow@@@Z @ 25 NONAME ; class CAlfCompositionPixelSource * CAlfCompositionPixelSource::NewL(class MAlfBufferProvider &, class RWindow *)
	??1CAlfCompositionSource@@UAE@XZ @ 26 NONAME ; CAlfCompositionSource::~CAlfCompositionSource(void)
	?Suspend@CAlfCompositionPixelSource@@QAEXXZ @ 27 NONAME ; void CAlfCompositionPixelSource::Suspend(void)
	?SetExtent@CAlfCompositionPixelSource@@UAEHABVTRect@@H@Z @ 28 NONAME ; int CAlfCompositionPixelSource::SetExtent(class TRect const &, int)
	?SetIsBackgroundAnim@CAlfCompositionSource@@UAEXH@Z @ 29 NONAME ; void CAlfCompositionSource::SetIsBackgroundAnim(int)
	?EnableAlpha@CAlfCompositionSource@@UAEHH@Z @ 30 NONAME ; int CAlfCompositionSource::EnableAlpha(int)
	?HandleEventL@CAlfCompositionClientBase@@MAEXHPAX@Z @ 31 NONAME ; void CAlfCompositionClientBase::HandleEventL(int, void *)
	?CreatePermissionToken@CAlfCompositionSource@@QAEHHH@Z @ 32 NONAME ; int CAlfCompositionSource::CreatePermissionToken(int, int)
	?EnableKeyboard@CAlfCompositionSource@@QAEXHH@Z @ 33 NONAME ; void CAlfCompositionSource::EnableKeyboard(int, int)
	?RemoveObserver@CAlfCompositionSource@@QAEXAAVMAlfCompositionObserver@@@Z @ 34 NONAME ; void CAlfCompositionSource::RemoveObserver(class MAlfCompositionObserver &)
	?NewL@CAlfCompositionHost@@SAPAV1@HH@Z @ 35 NONAME ; class CAlfCompositionHost * CAlfCompositionHost::NewL(int, int)
	?ActivateL@CAlfCompositionPixelSource@@QAEXXZ @ 36 NONAME ; void CAlfCompositionPixelSource::ActivateL(void)
	?SetExtent@CAlfCompositionSource@@UAEHABVTRect@@H@Z @ 37 NONAME ; int CAlfCompositionSource::SetExtent(class TRect const &, int)
	?NewL@CAlfCompositionSource@@SAPAV1@AAVRWindow@@@Z @ 38 NONAME ; class CAlfCompositionSource * CAlfCompositionSource::NewL(class RWindow &)
	?SendEvent@CAlfCompositionClientBase@@IAEHHPBXH@Z @ 39 NONAME ; int CAlfCompositionClientBase::SendEvent(int, void const *, int)
	??1CAlfCompositionCntrlClient@@UAE@XZ @ 40 NONAME ; CAlfCompositionCntrlClient::~CAlfCompositionCntrlClient(void)
	?SetSourceRect@CAlfCompositionSource@@UAEHABVTRect@@@Z @ 41 NONAME ; int CAlfCompositionSource::SetSourceRect(class TRect const &)
	?GetListOfInactiveWindowGroupsWSurfaces@RAlfBridgerClient@@QAEHPAV?$RArray@H@@@Z @ 42 NONAME ; int RAlfBridgerClient::GetListOfInactiveWindowGroupsWSurfaces(class RArray<int> *)
	?NewL@CAlfCompositionPixelSource@@SAPAV1@AAVMAlfBufferProvider@@HPAVRWindow@@@Z @ 43 NONAME ; class CAlfCompositionPixelSource * CAlfCompositionPixelSource::NewL(class MAlfBufferProvider &, int, class RWindow *)
	?ActivateSyncL@CAlfCompositionPixelSource@@QAEXXZ @ 44 NONAME ; void CAlfCompositionPixelSource::ActivateSyncL(void)
	?EffectsCount@RAlfBridgerClient@@QAEHXZ @ 45 NONAME ; SBS RULES OK
	?ActiveEffectsCount@CAlfEffectObserver@@QAEHXZ @ 46 NONAME ; int CAlfEffectObserver::ActiveEffectsCount(void)
	?NewL@CAlfEffectObserver@@SAPAV1@XZ @ 47 NONAME ; class CAlfEffectObserver * CAlfEffectObserver::NewL(void)
	??1CAlfEffectObserver@@UAE@XZ @ 48 NONAME ; CAlfEffectObserver::~CAlfEffectObserver(void)
	?SubscribeCallbackL@CAlfEffectObserver@@QAEXPAVMAlfEffectObserver@1@HH@Z @ 49 NONAME ; void CAlfEffectObserver::SubscribeCallbackL(class CAlfEffectObserver::MAlfEffectObserver *, int, int)
	?GetListOfWindowGroupsWSurfaces@RAlfBridgerClient@@QAEHPAV?$RArray@H@@@Z @ 50 NONAME ; int RAlfBridgerClient::GetListOfWindowGroupsWSurfaces(class RArray<int> *)
	?SetDistractionWindow@CAlfEffectObserver@@QAEXABVRWindowTreeNode@@H@Z @ 51 NONAME ; void CAlfEffectObserver::SetDistractionWindow(class RWindowTreeNode const &, int)

